sequencetools.CyclicList
========================

.. inheritance-diagram:: abjad.tools.sequencetools.CyclicList.CyclicList.CyclicList
   :private-bases:

.. autoclass:: abjad.tools.sequencetools.CyclicList.CyclicList.CyclicList

Methods
-------

.. automethod:: abjad.tools.sequencetools.CyclicList.CyclicList.CyclicList.append

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.sequencetools.CyclicList.CyclicList.CyclicList.count

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.sequencetools.CyclicList.CyclicList.CyclicList.extend

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.sequencetools.CyclicList.CyclicList.CyclicList.index

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.sequencetools.CyclicList.CyclicList.CyclicList.insert

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.sequencetools.CyclicList.CyclicList.CyclicList.pop

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.sequencetools.CyclicList.CyclicList.CyclicList.remove

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.sequencetools.CyclicList.CyclicList.CyclicList.reverse

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.sequencetools.CyclicList.CyclicList.CyclicList.sort

   .. note:: Inherited from `__builtin__.list`

Special Methods
---------------

.. automethod:: abjad.tools.sequencetools.CyclicList.CyclicList.CyclicList.__add__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.sequencetools.CyclicList.CyclicList.CyclicList.__contains__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.sequencetools.CyclicList.CyclicList.CyclicList.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.sequencetools.CyclicList.CyclicList.CyclicList.__delitem__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.sequencetools.CyclicList.CyclicList.CyclicList.__delslice__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.sequencetools.CyclicList.CyclicList.CyclicList.__eq__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.sequencetools.CyclicList.CyclicList.CyclicList.__ge__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.sequencetools.CyclicList.CyclicList.CyclicList.__getitem__

.. automethod:: abjad.tools.sequencetools.CyclicList.CyclicList.CyclicList.__getslice__

.. automethod:: abjad.tools.sequencetools.CyclicList.CyclicList.CyclicList.__gt__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.sequencetools.CyclicList.CyclicList.CyclicList.__iadd__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.sequencetools.CyclicList.CyclicList.CyclicList.__imul__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.sequencetools.CyclicList.CyclicList.CyclicList.__iter__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.sequencetools.CyclicList.CyclicList.CyclicList.__le__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.sequencetools.CyclicList.CyclicList.CyclicList.__len__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.sequencetools.CyclicList.CyclicList.CyclicList.__lt__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.sequencetools.CyclicList.CyclicList.CyclicList.__mul__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.sequencetools.CyclicList.CyclicList.CyclicList.__ne__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.sequencetools.CyclicList.CyclicList.CyclicList.__repr__

.. automethod:: abjad.tools.sequencetools.CyclicList.CyclicList.CyclicList.__reversed__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.sequencetools.CyclicList.CyclicList.CyclicList.__rmul__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.sequencetools.CyclicList.CyclicList.CyclicList.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.sequencetools.CyclicList.CyclicList.CyclicList.__setitem__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.sequencetools.CyclicList.CyclicList.CyclicList.__setslice__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.sequencetools.CyclicList.CyclicList.CyclicList.__str__
